Changelog
============

v0.2 (2015-10-20)
---------------------

* Add support assertRegex/assertRegexpMatches, assertNotRegex
  assertRaisesRegex/assertRaisesRegexp assertWarnsRegex.

* `unittest2pytest` is now a `pytest` subproject.

* Minor fixes.


v0.1 (2015-10-16)
---------------------

* Initial release

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 coding: utf-8
 End:
